==> haskell-network-run-0.3.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.0
visibility:           public
id:                   network-run-0.3.0-4Mi6V7kpr0aGy7D0LslN2p
key:                  network-run-0.3.0-4Mi6V7kpr0aGy7D0LslN2p
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  a5d731a308d11aa3ddd97bf066e0c78d
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.0-4Mi6V7kpr0aGy7D0LslN2p
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-HNOpCulLIRrH0UV3cvGeTA
    time-manager-0.0.1-JpazuCSWNGl3j8BSFP9udh

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-run-0.3.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.0
visibility:           public
id:                   network-run-0.3.0-LLJvOXgffYLG78z1DoiZ55
key:                  network-run-0.3.0-LLJvOXgffYLG78z1DoiZ55
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  ff29bab82e353a40b56419b457396d73
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.0-LLJvOXgffYLG78z1DoiZ55
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-ItBhIFDvz12FCCKfYobIMX
    time-manager-0.0.1-64S2xvxBdqSLjuALiCIYYz

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
